# Generated by Django 4.0 on 2022-09-24 23:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserExternalData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('external_id', models.IntegerField(verbose_name='External ID')),
                ('fullname', models.CharField(max_length=200, verbose_name='Full name')),
                ('user_rel', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='user_external_data_rel', to='auth.user', verbose_name='User')),
            ],
            options={
                'verbose_name': "User's external data",
                'verbose_name_plural': 'Users external data',
            },
        ),
    ]
